/*

  This file is a part of GRALE, a library to facilitate the simulation
  and inversion of gravitational lenses.

  Copyright (C) 2008-2012 Jori Liesenborgs

  Contact: jori.liesenborgs@gmail.com
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  
*/

#ifndef GRALE_AREALENSINVERSIONGAFACTORYPARAMS_H

#define GRALE_AREALENSINVERSIONGAFACTORYPARAMS_H

#include "graleconfig.h"
#include "lensinversiongafactoryparams.h"
#include "vector2d.h"
#include <list>
#include <string>

namespace grale
{

class ImagesDataExtended;

class GRALE_IMPORTEXPORT AreaLensInversionGAFactoryParams : public LensInversionGAFactoryParams
{
public:
	AreaLensInversionGAFactoryParams();
	~AreaLensInversionGAFactoryParams();

	void init(int maxgenerations, const std::list<ImagesDataExtended *> &images, double D_d,
		  Vector2D<double> center, double areasize, bool copyimages);

	int getMaximumNumberOfGenerations() const						{ return maxgenerations; }
	double getD_d() const									{ return D_d; }
	double getAreaSize() const								{ return areasize; }
	Vector2D<double> getCenter() const							{ return center; }
	const std::list<ImagesDataExtended *> &getImages() const				{ return images; }
	
	bool write(serut::SerializationInterface &si) const;
	bool read(serut::SerializationInterface &si);
	
	// Override this if a derived implementation is used!
	virtual AreaLensInversionGAFactoryParams *createCopy() const				{ AreaLensInversionGAFactoryParams *p = new AreaLensInversionGAFactoryParams(); p->init(maxgenerations, images, D_d, center, areasize, true); return p; }
	virtual bool loadExtraParameters(const std::string &fname);
protected:
	virtual bool writeInternal(serut::SerializationInterface &si) const					{ return true; }
	virtual bool readInternal(serut::SerializationInterface &si)						{ return true; }
private:
	int maxgenerations;
	bool deleteimages;
	double D_d;
	double areasize;
	Vector2D<double> center;
	std::list<ImagesDataExtended *> images;
};
	
} // end namespace

#endif // GRALE_AREALENSINVERSIONGAFACTORYPARAMS_H
