/*

  This file is a part of GRALE, a library to facilitate the simulation
  and inversion of gravitational lenses.

  Copyright (C) 2008-2012 Jori Liesenborgs

  Contact: jori.liesenborgs@gmail.com
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  
*/

#ifndef GRALE_GRIDLENSINVERSIONGAFACTORYPARAMS_H

#define GRALE_GRIDLENSINVERSIONGAFACTORYPARAMS_H

#include "graleconfig.h"
#include "lensinversiongafactoryparams.h"
#include "grid.h"
#include <list>

namespace grale
{

class ImagesDataExtended;
class GravitationalLens;

class GRALE_IMPORTEXPORT GridLensInversionGAFactoryParams : public LensInversionGAFactoryParams
{
public:
	enum BasisFunctionType { PlummerBasis, SquareBasis, GaussBasis };
	enum MassSheetSearchType { None, Genome, Loop };
	
	GridLensInversionGAFactoryParams();
	GridLensInversionGAFactoryParams(int maxgenerations,
					 const std::list<ImagesDataExtended *> &images, 
			                 const std::list<GridSquare> &gridsquares, 
					 double D_d,
					 double z_d,
					 double massscale,
					 bool copyimages,
					 bool useweights = false,
					 BasisFunctionType basisFunction = PlummerBasis,
					 bool allowNegativeValues = false,
					 const GravitationalLens *pBaseLens = 0,
					 MassSheetSearchType sheetSearchType = None);
	~GridLensInversionGAFactoryParams();

	int getMaximumNumberOfGenerations() const								{ return maxgenerations; }
	double getD_d() const											{ return D_d; }
	double getZ_d() const											{ return z_d; }
	double getMassScale() const										{ return massscale; }
	const std::list<ImagesDataExtended *> &getImages() const						{ return images; }
	const std::list<GridSquare> &getGridSquares() const							{ return gridsquares; }
	bool useMassWeights() const										{ return usemassweights; }
	BasisFunctionType getBasisFunctionType() const								{ return basisfunction; }
	bool allowNegativeValues() const									{ return m_allowNegative; }
	const GravitationalLens *getBaseLens() const								{ return m_pBaseLens; }
	MassSheetSearchType getMassSheetSearchType() const							{ return m_massSheetSearchType; }
	
	bool write(serut::SerializationInterface &si) const;
	bool read(serut::SerializationInterface &si);
private:
	int maxgenerations;
	bool deleteimages;
	double D_d, massscale, z_d;
	std::list<ImagesDataExtended *> images;
	std::list<GridSquare> gridsquares;
	bool usemassweights;
	BasisFunctionType basisfunction;
	bool m_allowNegative;
	GravitationalLens *m_pBaseLens;
	MassSheetSearchType m_massSheetSearchType;
};
	
} // end namespace

#endif // GRALE_GRIDLENSINVERSIONGAFACTORYPARAMS_H
