/*

  This file is a part of GRALE, a library to facilitate the simulation
  and inversion of gravitational lenses.

  Copyright (C) 2008-2012 Jori Liesenborgs

  Contact: jori.liesenborgs@gmail.com
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  
*/

#ifndef GRALE_FITSIMAGE_H

#define GRALE_FITSIMAGE_H

#include "graleconfig.h"
#include "coordinateinterface.h"
#include <string>

namespace grale
{

class GRALE_IMPORTEXPORT FITSImage : public errut::ErrorBase
{
public:
	FITSImage();
	~FITSImage();
	bool initNoCoordinates(int w, int h);
	bool loadWCSCoordinates(const std::string &fname);
	bool loadRectCoordinates(const std::string &fname);
	bool loadNoCoordinates(const std::string &fname);
	bool save(const std::string &fname) const;
	const double *getPixels() const						{ return m_pPixels; }
	double getPixel(int x, int y) const					{ return m_pPixels[x + y*m_width]; }
	void setPixel(int x, int y, double value)				{ m_pPixels[x + y*m_width] = value; }
	const CoordinateInterface *getCoordinateInterface() const		{ return m_pCoordinates; }
	int getWidth() const							{ return m_width; }
	int getHeight() const							{ return m_height; }

	FITSImage *createCopy() const;
private:
	CoordinateInterface *m_pCoordinates;
	double *m_pPixels;
	int m_width, m_height;
	std::string m_header;
};

} // end namespace

#endif // GRALE_FITSIMAGE_H
