/*

  This file is a part of GRALE, a library to facilitate the simulation
  and inversion of gravitational lenses.

  Copyright (C) 2008-2012 Jori Liesenborgs

  Contact: jori.liesenborgs@gmail.com
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  
*/

/**
 * \file circularintegrator.h
 */

#ifndef GRALE_CIRCULARINTEGRATOR_H

#define GRALE_CIRCULARINTEGRATOR_H

#include "graleconfig.h"
#include "real2dfunctionintegrator.h"

namespace grale
{

/** This class can be used to integrate a 2D function over a circular area. */
class GRALE_IMPORTEXPORT CircularIntegrator : public Real2DFunctionIntegrator
{
public:
	CircularIntegrator(Vector2D<double> center, double startRadius, double stopRadius, int radiusSteps = 100, 
			   int angleSteps = 100);
	~CircularIntegrator();
	double integrate(Real2DFunction &f, bool abs = false) const;
private:
	Vector2D<double> m_center;
	double m_startRadius, m_stopRadius;
	double m_radialStepSize, m_angularStepSize;
	int m_rSteps, m_aSteps;
};

} // end namespace

#endif // GRALE_CIRCULARINTEGRATOR_H

