/*

  This file is a part of GRALE, a library to facilitate the simulation
  and inversion of gravitational lenses.

  Copyright (C) 2008-2012 Jori Liesenborgs

  Contact: jori.liesenborgs@gmail.com
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  
*/

#include "graleconfig.h"
#include "peakdistribution.h"
#include "realtype.h"
#include <stdint.h>
#include <time.h>

#include "debugnew.h"

namespace grale
{

PeakDistribution::PeakDistribution(double width, double max, const mogal::RandomNumberGenerator *pRndGen) : ProbabilityDistribution(pRndGen)
{
	m_width = width;
	m_fracPlusOne = max/width+1.0;
}

PeakDistribution::~PeakDistribution()
{
}

double PeakDistribution::pickNumber() const
{
	double y;

	y = pickRandomNumber();

	return (POW(m_fracPlusOne, y)-1.0)*m_width;
}

} // end namespace

