/*

  This file is a part of GRALE, a library to facilitate the simulation
  and inversion of gravitational lenses.

  Copyright (C) 2008-2012 Jori Liesenborgs

  Contact: jori.liesenborgs@gmail.com
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  
*/

#include "graleconfig.h"
#include "imageplaneasciiwriter.h"
#include "imageplane.h"
#include <stdio.h>

#include "debugnew.h"

namespace grale
{

bool ImagePlaneASCIIWriter::write(ImagePlane *p, int subSamples)
{
	if (caust)
	{
		const std::list<Vector2D<double> > &caustics = p->getCausticPoints();
		std::list<Vector2D<double> >::const_iterator it;

		for (it = caustics.begin() ; it != caustics.end() ; it++)
		{
			Vector2D<double> pos = (*it);
			pos /= scale;
			fprintf(f,"%30.30g\t %30.30g\n",(double)pos.getX(),(double)pos.getY());
		}
		fprintf(f,"\n\n");
	}
	if (crit)
	{
		const std::list<Vector2D<double> > &criticallines = p->getCriticalLinePoints();
		std::list<Vector2D<double> >::const_iterator it;

		for (it = criticallines.begin() ; it != criticallines.end() ; it++)
		{
			Vector2D<double> pos = (*it);
			pos /= scale;
			fprintf(f,"%30.30g\t %30.30g\n",(double)pos.getX(),(double)pos.getY());
		}
		fprintf(f,"\n\n");
	}
	if (srcs)
	{
		int x,y,numx,numy;

		numx = p->getNumXPixels();
		numy = p->getNumYPixels();

		for (y = 0 ; y < numy ; y++)
		{
			for (x = 0 ; x < numx ; x++)
			{
				double value = p->getSourceIntensityAccurate(x, y, subSamples);

				if (value > 0)
				{
					Vector2D<double> pos = p->getPixelCoordinate(x,y);
					pos /= scale;
					fprintf(f,"%30.30g\t %30.30g\t %30.30g\n", pos.getX(), pos.getY(), value);
				}
			}
		}
		fprintf(f,"\n\n");
	}
	if (im)
	{
		int x,y,numx,numy;

		numx = p->getNumXPixels();
		numy = p->getNumYPixels();

		for (y = 0 ; y < numy ; y++)
		{
			for (x = 0 ; x < numx ; x++)
			{
				double value = p->getImageIntensityAccurate(x,y,subSamples);

				if (value > 0)
				{
					Vector2D<double> pos = p->getPixelCoordinate(x,y);
					pos /= scale;
					fprintf(f,"%30.30g\t %30.30g %30.30g\n", pos.getX(), pos.getY(), value);
				}
			}
		}
		fprintf(f,"\n\n");
	}
	return true;
}

} // end namespace

