/*

  This file is a part of GRALE, a library to facilitate the simulation
  and inversion of gravitational lenses.

  Copyright (C) 2008-2012 Jori Liesenborgs

  Contact: jori.liesenborgs@gmail.com
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  
*/

#ifndef GRALE_IMAGEPLANEGNUPLOTWRITER_H

#define GRALE_IMAGEPLANEGNUPLOTWRITER_H

#include "graleconfig.h"
#include "imageplanewriter.h"
#include "realtype.h"
#include <string>
#include <stdio.h>

namespace grale
{

class GRALE_IMPORTEXPORT ImagePlaneGnuPlotWriter : public ImagePlaneWriter
{
public:
	ImagePlaneGnuPlotWriter(const std::string &fname,bool images,bool sources,bool criticallines,
			        bool caustics,double scale = 1.0, bool flipX = false)			{ filename = fname; im = images; srcs = sources; crit = criticallines; caust = caustics; ImagePlaneGnuPlotWriter::scale = scale; Xlabel = "X"; Ylabel = "Y"; grid = false; fontsize = 30; col = false; m_flipX = flipX; }
	~ImagePlaneGnuPlotWriter()							 		{ }
	void setXLabel(const std::string &s)								{ Xlabel = s; }
	void setYLabel(const std::string &s)								{ Ylabel = s; }
	void setGrid(bool g)										{ grid = g; }
	void setFontSize(int s)										{ fontsize = s; }
	void setColor(bool c)										{ col = c; }
	bool write(ImagePlane *p, int subSamples);
private:
	std::string filename;
	bool im,srcs,crit,caust;
	double scale;
	std::string Xlabel,Ylabel;
	bool grid,col;
	int fontsize;
	bool m_flipX;
};

} // end namespace

#endif // GRALE_IMAGEPLANEGNUPLOTWRITER_H

