/*

  This file is a part of GRALE, a library to facilitate the simulation
  and inversion of gravitational lenses.

  Copyright (C) 2008-2012 Jori Liesenborgs

  Contact: jori.liesenborgs@gmail.com
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  
*/

#ifndef GRALE_REAL2DFUNCTIONGNUPLOTPLOTTER_H

#define GRALE_REAL2DFUNCTIONGNUPLOTPLOTTER_H

#include "graleconfig.h"
#include "real2dfunctionplotter.h"
#include <string>

namespace grale
{

class GRALE_IMPORTEXPORT Real2DFunctionGnuPlotPlotter : public Real2DFunctionPlotter
{
public:
	Real2DFunctionGnuPlotPlotter(const std::string &fname,double xscale = 1.0L,double yscale = 1.0L,double zscale = 1.0L);
	~Real2DFunctionGnuPlotPlotter();
	void setColor(bool b) 										{ color = b; }
	void setXLabel(const std::string &s)								{ xlabel = s; }
	void setYLabel(const std::string &s)								{ ylabel = s; }
	void set3D(bool f)										{ flag3d = f; }
	void setAxes(bool f)										{ axes = f; }
	void setZSize(double z)										{ zsize = z; }
	bool plot(Real2DFunction &f,Vector2D<double> bottomleft,Vector2D<double> topright,int numxsteps,int numysteps);
private:
	double xscale,yscale,zscale;
	std::string filename;
	std::string xlabel,ylabel;
	bool color,flag3d,axes;
	double zsize;
};

} // end namespace

#endif // GRALE_REAL2DFUNCTIONGNUPLOTPLOTTER_H

