/*

  This file is a part of GRALE, a library to facilitate the simulation
  and inversion of gravitational lenses.

  Copyright (C) 2008-2012 Jori Liesenborgs

  Contact: jori.liesenborgs@gmail.com
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  
*/

#ifndef GRALE_SOURCEPLANE_H

#define GRALE_SOURCEPLANE_H

#include "graleconfig.h"
#include "vector2d.h"
#include "triangle2d.h"
#include <serut/serializationinterface.h>
#include <errut/errorbase.h>
#include <stdint.h>
#include <list>
#include <map>

namespace grale
{
	
class SourceImage;

class GRALE_IMPORTEXPORT SourcePlane : public errut::ErrorBase
{
public:
	SourcePlane(double D_s, double D_ds);
	~SourcePlane();
	double getD_s() const							{ return D_s; }
	double getD_ds() const							{ return D_ds; }

	double getSurfaceBrightness(Vector2D<double> beta) const;
	void getPointSourceIntensities(Triangle2D<double> area, std::list<Vector2DPlus> &pointSourceInfo) const;
	bool isSourceInRange(Vector2D<double> beta, double radius) const;

	const std::map<uint16_t, SourceImage *> &getSources() const		{ return sources; }
	
	bool write(serut::SerializationInterface &s,bool writesources = false) const;
	static bool read(serut::SerializationInterface &si,SourcePlane **sp,std::string &errstr, bool loadsources = true);
private:
	bool registerSource(SourceImage *s, uint16_t sourceID);
	void unregisterSource(SourceImage *s);
	
	double D_s,D_ds;
	std::map<uint16_t, SourceImage *> sources;

	friend class SourceImage;
};

} // end namespace

#endif // GRALE_SOURCEPLANE_H

